@@ -126,7 +126,10 @@ http_resp_read_headers(http_resp *a_resp, http_trans_conn *a_conn)
 	l_done = 1;
       if ((l_done == 0) && (a_conn->sync == HTTP_TRANS_ASYNC) && (l_rv == HTTP_TRANS_NOT_DONE))
 	return HTTP_TRANS_NOT_DONE;
-      if ((l_rv == HTTP_TRANS_DONE) && (a_conn->last_read == 0))
+      /* yes, that !l_done is ther because in the case of a 100
+         continue we well get back up to this loop without doing a
+         successful read. */
+      if ((!l_done) && (l_rv == HTTP_TRANS_DONE) && (a_conn->last_read == 0))
 	{
 	  a_conn->errstr = "Short read while reading http response headers";
 	  return HTTP_TRANS_ERR;
@@ -194,15 +197,16 @@ http_resp_read_headers(http_resp *a_resp, http_trans_conn *a_conn)
     l_done = 1;
   else
     l_done = 0;
-  /* set the start past the end of the reason phrase,
-     checking if there's a CRLF after it. */
-  while ((*l_cur_ptr == '\r') ||
-	 (*l_cur_ptr == '\n'))
-    l_cur_ptr++;
   /* make sure that it's not a continue. */
   if (a_resp->status_code == 100)
     {
-      http_trans_buf_clip(a_conn, l_cur_ptr);
+      /* look for the next \r\n\r\n and cut it off */
+      char *l_end_continue = http_trans_buf_has_patt(a_conn->io_buf,
+						     a_conn->io_buf_alloc,
+						     "\r\n\r\n", 4);
+      if (!l_end_continue)
+	return HTTP_TRANS_ERR;
+      http_trans_buf_clip(a_conn, l_end_continue + 4);
       l_start_body = NULL;
       a_resp->status_code = 0;
       l_done = 0;
@@ -211,6 +215,12 @@ http_resp_read_headers(http_resp *a_resp, http_trans_conn *a_conn)
       else
 	goto http_resp_reading_header_jump;
     }
+  /* set the start past the end of the reason phrase,
+     checking if there's a CRLF after it. */
+  while ((*l_cur_ptr == '\r') ||
+	 (*l_cur_ptr == '\n'))
+    l_cur_ptr++;
+
   /* start parsing out the headers */
   /* start at the beginning */
   l_start_header = l_cur_ptr;
